# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/criteria.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import age_range_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_age__range__type__pb2
from google.ads.google_ads.v1.proto.enums import app_payment_model_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_app__payment__model__type__pb2
from google.ads.google_ads.v1.proto.enums import content_label_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_content__label__type__pb2
from google.ads.google_ads.v1.proto.enums import day_of_week_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_day__of__week__pb2
from google.ads.google_ads.v1.proto.enums import device_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_device__pb2
from google.ads.google_ads.v1.proto.enums import gender_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_gender__type__pb2
from google.ads.google_ads.v1.proto.enums import hotel_date_selection_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2
from google.ads.google_ads.v1.proto.enums import income_range_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_income__range__type__pb2
from google.ads.google_ads.v1.proto.enums import interaction_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_interaction__type__pb2
from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.ads.google_ads.v1.proto.enums import listing_custom_attribute_index_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_listing__custom__attribute__index__pb2
from google.ads.google_ads.v1.proto.enums import listing_group_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_listing__group__type__pb2
from google.ads.google_ads.v1.proto.enums import location_group_radius_units_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_location__group__radius__units__pb2
from google.ads.google_ads.v1.proto.enums import minute_of_hour_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_minute__of__hour__pb2
from google.ads.google_ads.v1.proto.enums import parental_status_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_parental__status__type__pb2
from google.ads.google_ads.v1.proto.enums import preferred_content_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_preferred__content__type__pb2
from google.ads.google_ads.v1.proto.enums import product_bidding_category_level_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__bidding__category__level__pb2
from google.ads.google_ads.v1.proto.enums import product_channel_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__channel__pb2
from google.ads.google_ads.v1.proto.enums import product_channel_exclusivity_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2
from google.ads.google_ads.v1.proto.enums import product_condition_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__condition__pb2
from google.ads.google_ads.v1.proto.enums import product_type_level_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__type__level__pb2
from google.ads.google_ads.v1.proto.enums import proximity_radius_units_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_proximity__radius__units__pb2
from google.ads.google_ads.v1.proto.enums import webpage_condition_operand_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_webpage__condition__operand__pb2
from google.ads.google_ads.v1.proto.enums import webpage_condition_operator_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_webpage__condition__operator__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/criteria.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\rCriteriaProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n3google/ads/googleads_v1/proto/common/criteria.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x38google/ads/googleads_v1/proto/enums/age_range_type.proto\x1a@google/ads/googleads_v1/proto/enums/app_payment_model_type.proto\x1a<google/ads/googleads_v1/proto/enums/content_label_type.proto\x1a\x35google/ads/googleads_v1/proto/enums/day_of_week.proto\x1a\x30google/ads/googleads_v1/proto/enums/device.proto\x1a\x35google/ads/googleads_v1/proto/enums/gender_type.proto\x1a\x43google/ads/googleads_v1/proto/enums/hotel_date_selection_type.proto\x1a;google/ads/googleads_v1/proto/enums/income_range_type.proto\x1a:google/ads/googleads_v1/proto/enums/interaction_type.proto\x1a<google/ads/googleads_v1/proto/enums/keyword_match_type.proto\x1aHgoogle/ads/googleads_v1/proto/enums/listing_custom_attribute_index.proto\x1a<google/ads/googleads_v1/proto/enums/listing_group_type.proto\x1a\x45google/ads/googleads_v1/proto/enums/location_group_radius_units.proto\x1a\x38google/ads/googleads_v1/proto/enums/minute_of_hour.proto\x1a>google/ads/googleads_v1/proto/enums/parental_status_type.proto\x1a@google/ads/googleads_v1/proto/enums/preferred_content_type.proto\x1aHgoogle/ads/googleads_v1/proto/enums/product_bidding_category_level.proto\x1a\x39google/ads/googleads_v1/proto/enums/product_channel.proto\x1a\x45google/ads/googleads_v1/proto/enums/product_channel_exclusivity.proto\x1a;google/ads/googleads_v1/proto/enums/product_condition.proto\x1a<google/ads/googleads_v1/proto/enums/product_type_level.proto\x1a@google/ads/googleads_v1/proto/enums/proximity_radius_units.proto\x1a\x43google/ads/googleads_v1/proto/enums/webpage_condition_operand.proto\x1a\x44google/ads/googleads_v1/proto/enums/webpage_condition_operator.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x93\x01\n\x0bKeywordInfo\x12*\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x02 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.KeywordMatchTypeEnum.KeywordMatchType\":\n\rPlacementInfo\x12)\n\x03url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"[\n\x15MobileAppCategoryInfo\x12\x42\n\x1cmobile_app_category_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"q\n\x15MobileApplicationInfo\x12,\n\x06\x61pp_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"I\n\x0cLocationInfo\x12\x39\n\x13geo_target_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"L\n\nDeviceInfo\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.google.ads.googleads.v1.enums.DeviceEnum.Device\"r\n\x14PreferredContentInfo\x12Z\n\x04type\x18\x02 \x01(\x0e\x32L.google.ads.googleads.v1.enums.PreferredContentTypeEnum.PreferredContentType\"\xf1\x01\n\x10ListingGroupInfo\x12R\n\x04type\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.ListingGroupTypeEnum.ListingGroupType\x12H\n\ncase_value\x18\x02 \x01(\x0b\x32\x34.google.ads.googleads.v1.common.ListingDimensionInfo\x12?\n\x19parent_ad_group_criterion\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\\\n\x10ListingScopeInfo\x12H\n\ndimensions\x18\x02 \x03(\x0b\x32\x34.google.ads.googleads.v1.common.ListingDimensionInfo\"\x9b\t\n\x14ListingDimensionInfo\x12I\n\rlisting_brand\x18\x01 \x01(\x0b\x32\x30.google.ads.googleads.v1.common.ListingBrandInfoH\x00\x12?\n\x08hotel_id\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v1.common.HotelIdInfoH\x00\x12\x45\n\x0bhotel_class\x18\x03 \x01(\x0b\x32..google.ads.googleads.v1.common.HotelClassInfoH\x00\x12V\n\x14hotel_country_region\x18\x04 \x01(\x0b\x32\x36.google.ads.googleads.v1.common.HotelCountryRegionInfoH\x00\x12\x45\n\x0bhotel_state\x18\x05 \x01(\x0b\x32..google.ads.googleads.v1.common.HotelStateInfoH\x00\x12\x43\n\nhotel_city\x18\x06 \x01(\x0b\x32-.google.ads.googleads.v1.common.HotelCityInfoH\x00\x12^\n\x18listing_custom_attribute\x18\x07 \x01(\x0b\x32:.google.ads.googleads.v1.common.ListingCustomAttributeInfoH\x00\x12^\n\x18product_bidding_category\x18\r \x01(\x0b\x32:.google.ads.googleads.v1.common.ProductBiddingCategoryInfoH\x00\x12M\n\x0fproduct_channel\x18\x08 \x01(\x0b\x32\x32.google.ads.googleads.v1.common.ProductChannelInfoH\x00\x12\x64\n\x1bproduct_channel_exclusivity\x18\t \x01(\x0b\x32=.google.ads.googleads.v1.common.ProductChannelExclusivityInfoH\x00\x12Q\n\x11product_condition\x18\n \x01(\x0b\x32\x34.google.ads.googleads.v1.common.ProductConditionInfoH\x00\x12L\n\x0fproduct_item_id\x18\x0b \x01(\x0b\x32\x31.google.ads.googleads.v1.common.ProductItemIdInfoH\x00\x12G\n\x0cproduct_type\x18\x0c \x01(\x0b\x32/.google.ads.googleads.v1.common.ProductTypeInfoH\x00\x12`\n\x19unknown_listing_dimension\x18\x0e \x01(\x0b\x32;.google.ads.googleads.v1.common.UnknownListingDimensionInfoH\x00\x42\x0b\n\tdimension\"?\n\x10ListingBrandInfo\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\":\n\x0bHotelIdInfo\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"<\n\x0eHotelClassInfo\x12*\n\x05value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"X\n\x16HotelCountryRegionInfo\x12>\n\x18\x63ountry_region_criterion\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"G\n\x0eHotelStateInfo\x12\x35\n\x0fstate_criterion\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"E\n\rHotelCityInfo\x12\x34\n\x0e\x63ity_criterion\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb4\x01\n\x1aListingCustomAttributeInfo\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12i\n\x05index\x18\x02 \x01(\x0e\x32Z.google.ads.googleads.v1.enums.ListingCustomAttributeIndexEnum.ListingCustomAttributeIndex\"\xe4\x01\n\x1aProductBiddingCategoryInfo\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0c\x63ountry_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12i\n\x05level\x18\x03 \x01(\x0e\x32Z.google.ads.googleads.v1.enums.ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel\"g\n\x12ProductChannelInfo\x12Q\n\x07\x63hannel\x18\x01 \x01(\x0e\x32@.google.ads.googleads.v1.enums.ProductChannelEnum.ProductChannel\"\x94\x01\n\x1dProductChannelExclusivityInfo\x12s\n\x13\x63hannel_exclusivity\x18\x01 \x01(\x0e\x32V.google.ads.googleads.v1.enums.ProductChannelExclusivityEnum.ProductChannelExclusivity\"o\n\x14ProductConditionInfo\x12W\n\tcondition\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.ProductConditionEnum.ProductCondition\"@\n\x11ProductItemIdInfo\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x93\x01\n\x0fProductTypeInfo\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12S\n\x05level\x18\x02 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.ProductTypeLevelEnum.ProductTypeLevel\"\x1d\n\x1bUnknownListingDimensionInfo\"|\n\x1aHotelDateSelectionTypeInfo\x12^\n\x04type\x18\x01 \x01(\x0e\x32P.google.ads.googleads.v1.enums.HotelDateSelectionTypeEnum.HotelDateSelectionType\"}\n\x1dHotelAdvanceBookingWindowInfo\x12-\n\x08min_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08max_days\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"y\n\x15HotelLengthOfStayInfo\x12/\n\nmin_nights\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\nmax_nights\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"b\n\x13HotelCheckInDayInfo\x12K\n\x0b\x64\x61y_of_week\x18\x01 \x01(\x0e\x32\x36.google.ads.googleads.v1.enums.DayOfWeekEnum.DayOfWeek\"g\n\x13InteractionTypeInfo\x12P\n\x04type\x18\x01 \x01(\x0e\x32\x42.google.ads.googleads.v1.enums.InteractionTypeEnum.InteractionType\"\xe3\x02\n\x0e\x41\x64ScheduleInfo\x12R\n\x0cstart_minute\x18\x01 \x01(\x0e\x32<.google.ads.googleads.v1.enums.MinuteOfHourEnum.MinuteOfHour\x12P\n\nend_minute\x18\x02 \x01(\x0e\x32<.google.ads.googleads.v1.enums.MinuteOfHourEnum.MinuteOfHour\x12/\n\nstart_hour\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\x08\x65nd_hour\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12K\n\x0b\x64\x61y_of_week\x18\x05 \x01(\x0e\x32\x36.google.ads.googleads.v1.enums.DayOfWeekEnum.DayOfWeek\"Z\n\x0c\x41geRangeInfo\x12J\n\x04type\x18\x01 \x01(\x0e\x32<.google.ads.googleads.v1.enums.AgeRangeTypeEnum.AgeRangeType\"T\n\nGenderInfo\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.google.ads.googleads.v1.enums.GenderTypeEnum.GenderType\"c\n\x0fIncomeRangeInfo\x12P\n\x04type\x18\x01 \x01(\x0e\x32\x42.google.ads.googleads.v1.enums.IncomeRangeTypeEnum.IncomeRangeType\"l\n\x12ParentalStatusInfo\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.google.ads.googleads.v1.enums.ParentalStatusTypeEnum.ParentalStatusType\"B\n\x10YouTubeVideoInfo\x12.\n\x08video_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"F\n\x12YouTubeChannelInfo\x12\x30\n\nchannel_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"?\n\x0cUserListInfo\x12/\n\tuser_list\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa0\x02\n\rProximityInfo\x12?\n\tgeo_point\x18\x01 \x01(\x0b\x32,.google.ads.googleads.v1.common.GeoPointInfo\x12,\n\x06radius\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x62\n\x0cradius_units\x18\x03 \x01(\x0e\x32L.google.ads.googleads.v1.enums.ProximityRadiusUnitsEnum.ProximityRadiusUnits\x12<\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32+.google.ads.googleads.v1.common.AddressInfo\"\x8f\x01\n\x0cGeoPointInfo\x12?\n\x1alongitude_in_micro_degrees\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12>\n\x19latitude_in_micro_degrees\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xfc\x02\n\x0b\x41\x64\x64ressInfo\x12\x31\n\x0bpostal_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rprovince_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rprovince_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0estreet_address\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fstreet_address2\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcity_name\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"m\n\tTopicInfo\x12\x34\n\x0etopic_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04path\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"G\n\x0cLanguageInfo\x12\x37\n\x11language_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"?\n\x0bIpBlockInfo\x12\x30\n\nip_address\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"f\n\x10\x43ontentLabelInfo\x12R\n\x04type\x18\x01 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.ContentLabelTypeEnum.ContentLabelType\"E\n\x0b\x43\x61rrierInfo\x12\x36\n\x10\x63\x61rrier_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"P\n\x10UserInterestInfo\x12<\n\x16user_interest_category\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x8d\x01\n\x0bWebpageInfo\x12\x34\n\x0e\x63riterion_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\nconditions\x18\x02 \x03(\x0b\x32\x34.google.ads.googleads.v1.common.WebpageConditionInfo\"\x93\x02\n\x14WebpageConditionInfo\x12\x63\n\x07operand\x18\x01 \x01(\x0e\x32R.google.ads.googleads.v1.enums.WebpageConditionOperandEnum.WebpageConditionOperand\x12\x66\n\x08operator\x18\x02 \x01(\x0e\x32T.google.ads.googleads.v1.enums.WebpageConditionOperatorEnum.WebpageConditionOperator\x12.\n\x08\x61rgument\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"e\n\x1aOperatingSystemVersionInfo\x12G\n!operating_system_version_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"o\n\x13\x41ppPaymentModelInfo\x12X\n\x04type\x18\x01 \x01(\x0e\x32J.google.ads.googleads.v1.enums.AppPaymentModelTypeEnum.AppPaymentModelType\"P\n\x10MobileDeviceInfo\x12<\n\x16mobile_device_constant\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"K\n\x12\x43ustomAffinityInfo\x12\x35\n\x0f\x63ustom_affinity\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"G\n\x10\x43ustomIntentInfo\x12\x33\n\rcustom_intent\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x94\x02\n\x11LocationGroupInfo\x12*\n\x04\x66\x65\x65\x64\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14geo_target_constants\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x06radius\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12j\n\x0cradius_units\x18\x04 \x01(\x0e\x32T.google.ads.googleads.v1.enums.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnitsB\xe8\x01\n\"com.google.ads.googleads.v1.commonB\rCriteriaProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_age__range__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_app__payment__model__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_content__label__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_day__of__week__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_device__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_gender__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_income__range__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_interaction__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_listing__custom__attribute__index__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_listing__group__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_location__group__radius__units__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_minute__of__hour__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_parental__status__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_preferred__content__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__bidding__category__level__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__channel__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__condition__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__type__level__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_proximity__radius__units__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_webpage__condition__operand__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_webpage__condition__operator__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDINFO = _descriptor.Descriptor(
  name='KeywordInfo',
  full_name='google.ads.googleads.v1.common.KeywordInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v1.common.KeywordInfo.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v1.common.KeywordInfo.match_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=1822,
)


_PLACEMENTINFO = _descriptor.Descriptor(
  name='PlacementInfo',
  full_name='google.ads.googleads.v1.common.PlacementInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='google.ads.googleads.v1.common.PlacementInfo.url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1824,
  serialized_end=1882,
)


_MOBILEAPPCATEGORYINFO = _descriptor.Descriptor(
  name='MobileAppCategoryInfo',
  full_name='google.ads.googleads.v1.common.MobileAppCategoryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mobile_app_category_constant', full_name='google.ads.googleads.v1.common.MobileAppCategoryInfo.mobile_app_category_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1884,
  serialized_end=1975,
)


_MOBILEAPPLICATIONINFO = _descriptor.Descriptor(
  name='MobileApplicationInfo',
  full_name='google.ads.googleads.v1.common.MobileApplicationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='google.ads.googleads.v1.common.MobileApplicationInfo.app_id', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.common.MobileApplicationInfo.name', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1977,
  serialized_end=2090,
)


_LOCATIONINFO = _descriptor.Descriptor(
  name='LocationInfo',
  full_name='google.ads.googleads.v1.common.LocationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_target_constant', full_name='google.ads.googleads.v1.common.LocationInfo.geo_target_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2092,
  serialized_end=2165,
)


_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='google.ads.googleads.v1.common.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.DeviceInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2167,
  serialized_end=2243,
)


_PREFERREDCONTENTINFO = _descriptor.Descriptor(
  name='PreferredContentInfo',
  full_name='google.ads.googleads.v1.common.PreferredContentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.PreferredContentInfo.type', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2245,
  serialized_end=2359,
)


_LISTINGGROUPINFO = _descriptor.Descriptor(
  name='ListingGroupInfo',
  full_name='google.ads.googleads.v1.common.ListingGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.ListingGroupInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='case_value', full_name='google.ads.googleads.v1.common.ListingGroupInfo.case_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_ad_group_criterion', full_name='google.ads.googleads.v1.common.ListingGroupInfo.parent_ad_group_criterion', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2362,
  serialized_end=2603,
)


_LISTINGSCOPEINFO = _descriptor.Descriptor(
  name='ListingScopeInfo',
  full_name='google.ads.googleads.v1.common.ListingScopeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='google.ads.googleads.v1.common.ListingScopeInfo.dimensions', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2605,
  serialized_end=2697,
)


_LISTINGDIMENSIONINFO = _descriptor.Descriptor(
  name='ListingDimensionInfo',
  full_name='google.ads.googleads.v1.common.ListingDimensionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='listing_brand', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.listing_brand', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_id', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.hotel_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_class', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.hotel_class', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_country_region', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.hotel_country_region', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_state', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.hotel_state', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_city', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.hotel_city', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listing_custom_attribute', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.listing_custom_attribute', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_bidding_category', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.product_bidding_category', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_channel', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.product_channel', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_channel_exclusivity', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.product_channel_exclusivity', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_condition', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.product_condition', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_item_id', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.product_item_id', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='product_type', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.product_type', index=12,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unknown_listing_dimension', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.unknown_listing_dimension', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='dimension', full_name='google.ads.googleads.v1.common.ListingDimensionInfo.dimension',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2700,
  serialized_end=3879,
)


_LISTINGBRANDINFO = _descriptor.Descriptor(
  name='ListingBrandInfo',
  full_name='google.ads.googleads.v1.common.ListingBrandInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.ListingBrandInfo.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3881,
  serialized_end=3944,
)


_HOTELIDINFO = _descriptor.Descriptor(
  name='HotelIdInfo',
  full_name='google.ads.googleads.v1.common.HotelIdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.HotelIdInfo.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3946,
  serialized_end=4004,
)


_HOTELCLASSINFO = _descriptor.Descriptor(
  name='HotelClassInfo',
  full_name='google.ads.googleads.v1.common.HotelClassInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.HotelClassInfo.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4006,
  serialized_end=4066,
)


_HOTELCOUNTRYREGIONINFO = _descriptor.Descriptor(
  name='HotelCountryRegionInfo',
  full_name='google.ads.googleads.v1.common.HotelCountryRegionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_region_criterion', full_name='google.ads.googleads.v1.common.HotelCountryRegionInfo.country_region_criterion', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4068,
  serialized_end=4156,
)


_HOTELSTATEINFO = _descriptor.Descriptor(
  name='HotelStateInfo',
  full_name='google.ads.googleads.v1.common.HotelStateInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_criterion', full_name='google.ads.googleads.v1.common.HotelStateInfo.state_criterion', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4158,
  serialized_end=4229,
)


_HOTELCITYINFO = _descriptor.Descriptor(
  name='HotelCityInfo',
  full_name='google.ads.googleads.v1.common.HotelCityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='city_criterion', full_name='google.ads.googleads.v1.common.HotelCityInfo.city_criterion', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4231,
  serialized_end=4300,
)


_LISTINGCUSTOMATTRIBUTEINFO = _descriptor.Descriptor(
  name='ListingCustomAttributeInfo',
  full_name='google.ads.googleads.v1.common.ListingCustomAttributeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.ListingCustomAttributeInfo.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='google.ads.googleads.v1.common.ListingCustomAttributeInfo.index', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4303,
  serialized_end=4483,
)


_PRODUCTBIDDINGCATEGORYINFO = _descriptor.Descriptor(
  name='ProductBiddingCategoryInfo',
  full_name='google.ads.googleads.v1.common.ProductBiddingCategoryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.common.ProductBiddingCategoryInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v1.common.ProductBiddingCategoryInfo.country_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='google.ads.googleads.v1.common.ProductBiddingCategoryInfo.level', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4486,
  serialized_end=4714,
)


_PRODUCTCHANNELINFO = _descriptor.Descriptor(
  name='ProductChannelInfo',
  full_name='google.ads.googleads.v1.common.ProductChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='google.ads.googleads.v1.common.ProductChannelInfo.channel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4716,
  serialized_end=4819,
)


_PRODUCTCHANNELEXCLUSIVITYINFO = _descriptor.Descriptor(
  name='ProductChannelExclusivityInfo',
  full_name='google.ads.googleads.v1.common.ProductChannelExclusivityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_exclusivity', full_name='google.ads.googleads.v1.common.ProductChannelExclusivityInfo.channel_exclusivity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4822,
  serialized_end=4970,
)


_PRODUCTCONDITIONINFO = _descriptor.Descriptor(
  name='ProductConditionInfo',
  full_name='google.ads.googleads.v1.common.ProductConditionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='condition', full_name='google.ads.googleads.v1.common.ProductConditionInfo.condition', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4972,
  serialized_end=5083,
)


_PRODUCTITEMIDINFO = _descriptor.Descriptor(
  name='ProductItemIdInfo',
  full_name='google.ads.googleads.v1.common.ProductItemIdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.ProductItemIdInfo.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5085,
  serialized_end=5149,
)


_PRODUCTTYPEINFO = _descriptor.Descriptor(
  name='ProductTypeInfo',
  full_name='google.ads.googleads.v1.common.ProductTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.ProductTypeInfo.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='google.ads.googleads.v1.common.ProductTypeInfo.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5152,
  serialized_end=5299,
)


_UNKNOWNLISTINGDIMENSIONINFO = _descriptor.Descriptor(
  name='UnknownListingDimensionInfo',
  full_name='google.ads.googleads.v1.common.UnknownListingDimensionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5301,
  serialized_end=5330,
)


_HOTELDATESELECTIONTYPEINFO = _descriptor.Descriptor(
  name='HotelDateSelectionTypeInfo',
  full_name='google.ads.googleads.v1.common.HotelDateSelectionTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.HotelDateSelectionTypeInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5332,
  serialized_end=5456,
)


_HOTELADVANCEBOOKINGWINDOWINFO = _descriptor.Descriptor(
  name='HotelAdvanceBookingWindowInfo',
  full_name='google.ads.googleads.v1.common.HotelAdvanceBookingWindowInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_days', full_name='google.ads.googleads.v1.common.HotelAdvanceBookingWindowInfo.min_days', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_days', full_name='google.ads.googleads.v1.common.HotelAdvanceBookingWindowInfo.max_days', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5458,
  serialized_end=5583,
)


_HOTELLENGTHOFSTAYINFO = _descriptor.Descriptor(
  name='HotelLengthOfStayInfo',
  full_name='google.ads.googleads.v1.common.HotelLengthOfStayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_nights', full_name='google.ads.googleads.v1.common.HotelLengthOfStayInfo.min_nights', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_nights', full_name='google.ads.googleads.v1.common.HotelLengthOfStayInfo.max_nights', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5585,
  serialized_end=5706,
)


_HOTELCHECKINDAYINFO = _descriptor.Descriptor(
  name='HotelCheckInDayInfo',
  full_name='google.ads.googleads.v1.common.HotelCheckInDayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='day_of_week', full_name='google.ads.googleads.v1.common.HotelCheckInDayInfo.day_of_week', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5708,
  serialized_end=5806,
)


_INTERACTIONTYPEINFO = _descriptor.Descriptor(
  name='InteractionTypeInfo',
  full_name='google.ads.googleads.v1.common.InteractionTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.InteractionTypeInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5808,
  serialized_end=5911,
)


_ADSCHEDULEINFO = _descriptor.Descriptor(
  name='AdScheduleInfo',
  full_name='google.ads.googleads.v1.common.AdScheduleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_minute', full_name='google.ads.googleads.v1.common.AdScheduleInfo.start_minute', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_minute', full_name='google.ads.googleads.v1.common.AdScheduleInfo.end_minute', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_hour', full_name='google.ads.googleads.v1.common.AdScheduleInfo.start_hour', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_hour', full_name='google.ads.googleads.v1.common.AdScheduleInfo.end_hour', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='day_of_week', full_name='google.ads.googleads.v1.common.AdScheduleInfo.day_of_week', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5914,
  serialized_end=6269,
)


_AGERANGEINFO = _descriptor.Descriptor(
  name='AgeRangeInfo',
  full_name='google.ads.googleads.v1.common.AgeRangeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.AgeRangeInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6271,
  serialized_end=6361,
)


_GENDERINFO = _descriptor.Descriptor(
  name='GenderInfo',
  full_name='google.ads.googleads.v1.common.GenderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.GenderInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6363,
  serialized_end=6447,
)


_INCOMERANGEINFO = _descriptor.Descriptor(
  name='IncomeRangeInfo',
  full_name='google.ads.googleads.v1.common.IncomeRangeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.IncomeRangeInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6449,
  serialized_end=6548,
)


_PARENTALSTATUSINFO = _descriptor.Descriptor(
  name='ParentalStatusInfo',
  full_name='google.ads.googleads.v1.common.ParentalStatusInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.ParentalStatusInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6550,
  serialized_end=6658,
)


_YOUTUBEVIDEOINFO = _descriptor.Descriptor(
  name='YouTubeVideoInfo',
  full_name='google.ads.googleads.v1.common.YouTubeVideoInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='video_id', full_name='google.ads.googleads.v1.common.YouTubeVideoInfo.video_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6660,
  serialized_end=6726,
)


_YOUTUBECHANNELINFO = _descriptor.Descriptor(
  name='YouTubeChannelInfo',
  full_name='google.ads.googleads.v1.common.YouTubeChannelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='google.ads.googleads.v1.common.YouTubeChannelInfo.channel_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6728,
  serialized_end=6798,
)


_USERLISTINFO = _descriptor.Descriptor(
  name='UserListInfo',
  full_name='google.ads.googleads.v1.common.UserListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_list', full_name='google.ads.googleads.v1.common.UserListInfo.user_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6800,
  serialized_end=6863,
)


_PROXIMITYINFO = _descriptor.Descriptor(
  name='ProximityInfo',
  full_name='google.ads.googleads.v1.common.ProximityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_point', full_name='google.ads.googleads.v1.common.ProximityInfo.geo_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius', full_name='google.ads.googleads.v1.common.ProximityInfo.radius', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius_units', full_name='google.ads.googleads.v1.common.ProximityInfo.radius_units', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='google.ads.googleads.v1.common.ProximityInfo.address', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6866,
  serialized_end=7154,
)


_GEOPOINTINFO = _descriptor.Descriptor(
  name='GeoPointInfo',
  full_name='google.ads.googleads.v1.common.GeoPointInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='longitude_in_micro_degrees', full_name='google.ads.googleads.v1.common.GeoPointInfo.longitude_in_micro_degrees', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude_in_micro_degrees', full_name='google.ads.googleads.v1.common.GeoPointInfo.latitude_in_micro_degrees', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7157,
  serialized_end=7300,
)


_ADDRESSINFO = _descriptor.Descriptor(
  name='AddressInfo',
  full_name='google.ads.googleads.v1.common.AddressInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='postal_code', full_name='google.ads.googleads.v1.common.AddressInfo.postal_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='province_code', full_name='google.ads.googleads.v1.common.AddressInfo.province_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v1.common.AddressInfo.country_code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='province_name', full_name='google.ads.googleads.v1.common.AddressInfo.province_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='street_address', full_name='google.ads.googleads.v1.common.AddressInfo.street_address', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='street_address2', full_name='google.ads.googleads.v1.common.AddressInfo.street_address2', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city_name', full_name='google.ads.googleads.v1.common.AddressInfo.city_name', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7303,
  serialized_end=7683,
)


_TOPICINFO = _descriptor.Descriptor(
  name='TopicInfo',
  full_name='google.ads.googleads.v1.common.TopicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_constant', full_name='google.ads.googleads.v1.common.TopicInfo.topic_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='google.ads.googleads.v1.common.TopicInfo.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7685,
  serialized_end=7794,
)


_LANGUAGEINFO = _descriptor.Descriptor(
  name='LanguageInfo',
  full_name='google.ads.googleads.v1.common.LanguageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_constant', full_name='google.ads.googleads.v1.common.LanguageInfo.language_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7796,
  serialized_end=7867,
)


_IPBLOCKINFO = _descriptor.Descriptor(
  name='IpBlockInfo',
  full_name='google.ads.googleads.v1.common.IpBlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='google.ads.googleads.v1.common.IpBlockInfo.ip_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7869,
  serialized_end=7932,
)


_CONTENTLABELINFO = _descriptor.Descriptor(
  name='ContentLabelInfo',
  full_name='google.ads.googleads.v1.common.ContentLabelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.ContentLabelInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7934,
  serialized_end=8036,
)


_CARRIERINFO = _descriptor.Descriptor(
  name='CarrierInfo',
  full_name='google.ads.googleads.v1.common.CarrierInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='carrier_constant', full_name='google.ads.googleads.v1.common.CarrierInfo.carrier_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8038,
  serialized_end=8107,
)


_USERINTERESTINFO = _descriptor.Descriptor(
  name='UserInterestInfo',
  full_name='google.ads.googleads.v1.common.UserInterestInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_interest_category', full_name='google.ads.googleads.v1.common.UserInterestInfo.user_interest_category', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8109,
  serialized_end=8189,
)


_WEBPAGEINFO = _descriptor.Descriptor(
  name='WebpageInfo',
  full_name='google.ads.googleads.v1.common.WebpageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='criterion_name', full_name='google.ads.googleads.v1.common.WebpageInfo.criterion_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='google.ads.googleads.v1.common.WebpageInfo.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8192,
  serialized_end=8333,
)


_WEBPAGECONDITIONINFO = _descriptor.Descriptor(
  name='WebpageConditionInfo',
  full_name='google.ads.googleads.v1.common.WebpageConditionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operand', full_name='google.ads.googleads.v1.common.WebpageConditionInfo.operand', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='google.ads.googleads.v1.common.WebpageConditionInfo.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='google.ads.googleads.v1.common.WebpageConditionInfo.argument', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8336,
  serialized_end=8611,
)


_OPERATINGSYSTEMVERSIONINFO = _descriptor.Descriptor(
  name='OperatingSystemVersionInfo',
  full_name='google.ads.googleads.v1.common.OperatingSystemVersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operating_system_version_constant', full_name='google.ads.googleads.v1.common.OperatingSystemVersionInfo.operating_system_version_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8613,
  serialized_end=8714,
)


_APPPAYMENTMODELINFO = _descriptor.Descriptor(
  name='AppPaymentModelInfo',
  full_name='google.ads.googleads.v1.common.AppPaymentModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.AppPaymentModelInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8716,
  serialized_end=8827,
)


_MOBILEDEVICEINFO = _descriptor.Descriptor(
  name='MobileDeviceInfo',
  full_name='google.ads.googleads.v1.common.MobileDeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mobile_device_constant', full_name='google.ads.googleads.v1.common.MobileDeviceInfo.mobile_device_constant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8829,
  serialized_end=8909,
)


_CUSTOMAFFINITYINFO = _descriptor.Descriptor(
  name='CustomAffinityInfo',
  full_name='google.ads.googleads.v1.common.CustomAffinityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_affinity', full_name='google.ads.googleads.v1.common.CustomAffinityInfo.custom_affinity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8911,
  serialized_end=8986,
)


_CUSTOMINTENTINFO = _descriptor.Descriptor(
  name='CustomIntentInfo',
  full_name='google.ads.googleads.v1.common.CustomIntentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_intent', full_name='google.ads.googleads.v1.common.CustomIntentInfo.custom_intent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8988,
  serialized_end=9059,
)


_LOCATIONGROUPINFO = _descriptor.Descriptor(
  name='LocationGroupInfo',
  full_name='google.ads.googleads.v1.common.LocationGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v1.common.LocationGroupInfo.feed', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constants', full_name='google.ads.googleads.v1.common.LocationGroupInfo.geo_target_constants', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius', full_name='google.ads.googleads.v1.common.LocationGroupInfo.radius', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radius_units', full_name='google.ads.googleads.v1.common.LocationGroupInfo.radius_units', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9062,
  serialized_end=9338,
)

_KEYWORDINFO.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDINFO.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
_PLACEMENTINFO.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MOBILEAPPCATEGORYINFO.fields_by_name['mobile_app_category_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MOBILEAPPLICATIONINFO.fields_by_name['app_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MOBILEAPPLICATIONINFO.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONINFO.fields_by_name['geo_target_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DEVICEINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_device__pb2._DEVICEENUM_DEVICE
_PREFERREDCONTENTINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_preferred__content__type__pb2._PREFERREDCONTENTTYPEENUM_PREFERREDCONTENTTYPE
_LISTINGGROUPINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_listing__group__type__pb2._LISTINGGROUPTYPEENUM_LISTINGGROUPTYPE
_LISTINGGROUPINFO.fields_by_name['case_value'].message_type = _LISTINGDIMENSIONINFO
_LISTINGGROUPINFO.fields_by_name['parent_ad_group_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LISTINGSCOPEINFO.fields_by_name['dimensions'].message_type = _LISTINGDIMENSIONINFO
_LISTINGDIMENSIONINFO.fields_by_name['listing_brand'].message_type = _LISTINGBRANDINFO
_LISTINGDIMENSIONINFO.fields_by_name['hotel_id'].message_type = _HOTELIDINFO
_LISTINGDIMENSIONINFO.fields_by_name['hotel_class'].message_type = _HOTELCLASSINFO
_LISTINGDIMENSIONINFO.fields_by_name['hotel_country_region'].message_type = _HOTELCOUNTRYREGIONINFO
_LISTINGDIMENSIONINFO.fields_by_name['hotel_state'].message_type = _HOTELSTATEINFO
_LISTINGDIMENSIONINFO.fields_by_name['hotel_city'].message_type = _HOTELCITYINFO
_LISTINGDIMENSIONINFO.fields_by_name['listing_custom_attribute'].message_type = _LISTINGCUSTOMATTRIBUTEINFO
_LISTINGDIMENSIONINFO.fields_by_name['product_bidding_category'].message_type = _PRODUCTBIDDINGCATEGORYINFO
_LISTINGDIMENSIONINFO.fields_by_name['product_channel'].message_type = _PRODUCTCHANNELINFO
_LISTINGDIMENSIONINFO.fields_by_name['product_channel_exclusivity'].message_type = _PRODUCTCHANNELEXCLUSIVITYINFO
_LISTINGDIMENSIONINFO.fields_by_name['product_condition'].message_type = _PRODUCTCONDITIONINFO
_LISTINGDIMENSIONINFO.fields_by_name['product_item_id'].message_type = _PRODUCTITEMIDINFO
_LISTINGDIMENSIONINFO.fields_by_name['product_type'].message_type = _PRODUCTTYPEINFO
_LISTINGDIMENSIONINFO.fields_by_name['unknown_listing_dimension'].message_type = _UNKNOWNLISTINGDIMENSIONINFO
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['listing_brand'])
_LISTINGDIMENSIONINFO.fields_by_name['listing_brand'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['hotel_id'])
_LISTINGDIMENSIONINFO.fields_by_name['hotel_id'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['hotel_class'])
_LISTINGDIMENSIONINFO.fields_by_name['hotel_class'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['hotel_country_region'])
_LISTINGDIMENSIONINFO.fields_by_name['hotel_country_region'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['hotel_state'])
_LISTINGDIMENSIONINFO.fields_by_name['hotel_state'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['hotel_city'])
_LISTINGDIMENSIONINFO.fields_by_name['hotel_city'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['listing_custom_attribute'])
_LISTINGDIMENSIONINFO.fields_by_name['listing_custom_attribute'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['product_bidding_category'])
_LISTINGDIMENSIONINFO.fields_by_name['product_bidding_category'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['product_channel'])
_LISTINGDIMENSIONINFO.fields_by_name['product_channel'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['product_channel_exclusivity'])
_LISTINGDIMENSIONINFO.fields_by_name['product_channel_exclusivity'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['product_condition'])
_LISTINGDIMENSIONINFO.fields_by_name['product_condition'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['product_item_id'])
_LISTINGDIMENSIONINFO.fields_by_name['product_item_id'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['product_type'])
_LISTINGDIMENSIONINFO.fields_by_name['product_type'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGDIMENSIONINFO.oneofs_by_name['dimension'].fields.append(
  _LISTINGDIMENSIONINFO.fields_by_name['unknown_listing_dimension'])
_LISTINGDIMENSIONINFO.fields_by_name['unknown_listing_dimension'].containing_oneof = _LISTINGDIMENSIONINFO.oneofs_by_name['dimension']
_LISTINGBRANDINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HOTELIDINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HOTELCLASSINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HOTELCOUNTRYREGIONINFO.fields_by_name['country_region_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HOTELSTATEINFO.fields_by_name['state_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HOTELCITYINFO.fields_by_name['city_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LISTINGCUSTOMATTRIBUTEINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LISTINGCUSTOMATTRIBUTEINFO.fields_by_name['index'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_listing__custom__attribute__index__pb2._LISTINGCUSTOMATTRIBUTEINDEXENUM_LISTINGCUSTOMATTRIBUTEINDEX
_PRODUCTBIDDINGCATEGORYINFO.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PRODUCTBIDDINGCATEGORYINFO.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTBIDDINGCATEGORYINFO.fields_by_name['level'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__bidding__category__level__pb2._PRODUCTBIDDINGCATEGORYLEVELENUM_PRODUCTBIDDINGCATEGORYLEVEL
_PRODUCTCHANNELINFO.fields_by_name['channel'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__channel__pb2._PRODUCTCHANNELENUM_PRODUCTCHANNEL
_PRODUCTCHANNELEXCLUSIVITYINFO.fields_by_name['channel_exclusivity'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__channel__exclusivity__pb2._PRODUCTCHANNELEXCLUSIVITYENUM_PRODUCTCHANNELEXCLUSIVITY
_PRODUCTCONDITIONINFO.fields_by_name['condition'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__condition__pb2._PRODUCTCONDITIONENUM_PRODUCTCONDITION
_PRODUCTITEMIDINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTTYPEINFO.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PRODUCTTYPEINFO.fields_by_name['level'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_product__type__level__pb2._PRODUCTTYPELEVELENUM_PRODUCTTYPELEVEL
_HOTELDATESELECTIONTYPEINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_hotel__date__selection__type__pb2._HOTELDATESELECTIONTYPEENUM_HOTELDATESELECTIONTYPE
_HOTELADVANCEBOOKINGWINDOWINFO.fields_by_name['min_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HOTELADVANCEBOOKINGWINDOWINFO.fields_by_name['max_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HOTELLENGTHOFSTAYINFO.fields_by_name['min_nights'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HOTELLENGTHOFSTAYINFO.fields_by_name['max_nights'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_HOTELCHECKINDAYINFO.fields_by_name['day_of_week'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_day__of__week__pb2._DAYOFWEEKENUM_DAYOFWEEK
_INTERACTIONTYPEINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_interaction__type__pb2._INTERACTIONTYPEENUM_INTERACTIONTYPE
_ADSCHEDULEINFO.fields_by_name['start_minute'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_minute__of__hour__pb2._MINUTEOFHOURENUM_MINUTEOFHOUR
_ADSCHEDULEINFO.fields_by_name['end_minute'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_minute__of__hour__pb2._MINUTEOFHOURENUM_MINUTEOFHOUR
_ADSCHEDULEINFO.fields_by_name['start_hour'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_ADSCHEDULEINFO.fields_by_name['end_hour'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_ADSCHEDULEINFO.fields_by_name['day_of_week'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_day__of__week__pb2._DAYOFWEEKENUM_DAYOFWEEK
_AGERANGEINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_age__range__type__pb2._AGERANGETYPEENUM_AGERANGETYPE
_GENDERINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_gender__type__pb2._GENDERTYPEENUM_GENDERTYPE
_INCOMERANGEINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_income__range__type__pb2._INCOMERANGETYPEENUM_INCOMERANGETYPE
_PARENTALSTATUSINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_parental__status__type__pb2._PARENTALSTATUSTYPEENUM_PARENTALSTATUSTYPE
_YOUTUBEVIDEOINFO.fields_by_name['video_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_YOUTUBECHANNELINFO.fields_by_name['channel_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERLISTINFO.fields_by_name['user_list'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROXIMITYINFO.fields_by_name['geo_point'].message_type = _GEOPOINTINFO
_PROXIMITYINFO.fields_by_name['radius'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_PROXIMITYINFO.fields_by_name['radius_units'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_proximity__radius__units__pb2._PROXIMITYRADIUSUNITSENUM_PROXIMITYRADIUSUNITS
_PROXIMITYINFO.fields_by_name['address'].message_type = _ADDRESSINFO
_GEOPOINTINFO.fields_by_name['longitude_in_micro_degrees'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_GEOPOINTINFO.fields_by_name['latitude_in_micro_degrees'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_ADDRESSINFO.fields_by_name['postal_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADDRESSINFO.fields_by_name['province_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADDRESSINFO.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADDRESSINFO.fields_by_name['province_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADDRESSINFO.fields_by_name['street_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADDRESSINFO.fields_by_name['street_address2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ADDRESSINFO.fields_by_name['city_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TOPICINFO.fields_by_name['topic_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TOPICINFO.fields_by_name['path'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LANGUAGEINFO.fields_by_name['language_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IPBLOCKINFO.fields_by_name['ip_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONTENTLABELINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_content__label__type__pb2._CONTENTLABELTYPEENUM_CONTENTLABELTYPE
_CARRIERINFO.fields_by_name['carrier_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_USERINTERESTINFO.fields_by_name['user_interest_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_WEBPAGEINFO.fields_by_name['criterion_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_WEBPAGEINFO.fields_by_name['conditions'].message_type = _WEBPAGECONDITIONINFO
_WEBPAGECONDITIONINFO.fields_by_name['operand'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_webpage__condition__operand__pb2._WEBPAGECONDITIONOPERANDENUM_WEBPAGECONDITIONOPERAND
_WEBPAGECONDITIONINFO.fields_by_name['operator'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_webpage__condition__operator__pb2._WEBPAGECONDITIONOPERATORENUM_WEBPAGECONDITIONOPERATOR
_WEBPAGECONDITIONINFO.fields_by_name['argument'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OPERATINGSYSTEMVERSIONINFO.fields_by_name['operating_system_version_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPPAYMENTMODELINFO.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_app__payment__model__type__pb2._APPPAYMENTMODELTYPEENUM_APPPAYMENTMODELTYPE
_MOBILEDEVICEINFO.fields_by_name['mobile_device_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMAFFINITYINFO.fields_by_name['custom_affinity'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMINTENTINFO.fields_by_name['custom_intent'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONGROUPINFO.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONGROUPINFO.fields_by_name['geo_target_constants'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LOCATIONGROUPINFO.fields_by_name['radius'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LOCATIONGROUPINFO.fields_by_name['radius_units'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_location__group__radius__units__pb2._LOCATIONGROUPRADIUSUNITSENUM_LOCATIONGROUPRADIUSUNITS
DESCRIPTOR.message_types_by_name['KeywordInfo'] = _KEYWORDINFO
DESCRIPTOR.message_types_by_name['PlacementInfo'] = _PLACEMENTINFO
DESCRIPTOR.message_types_by_name['MobileAppCategoryInfo'] = _MOBILEAPPCATEGORYINFO
DESCRIPTOR.message_types_by_name['MobileApplicationInfo'] = _MOBILEAPPLICATIONINFO
DESCRIPTOR.message_types_by_name['LocationInfo'] = _LOCATIONINFO
DESCRIPTOR.message_types_by_name['DeviceInfo'] = _DEVICEINFO
DESCRIPTOR.message_types_by_name['PreferredContentInfo'] = _PREFERREDCONTENTINFO
DESCRIPTOR.message_types_by_name['ListingGroupInfo'] = _LISTINGGROUPINFO
DESCRIPTOR.message_types_by_name['ListingScopeInfo'] = _LISTINGSCOPEINFO
DESCRIPTOR.message_types_by_name['ListingDimensionInfo'] = _LISTINGDIMENSIONINFO
DESCRIPTOR.message_types_by_name['ListingBrandInfo'] = _LISTINGBRANDINFO
DESCRIPTOR.message_types_by_name['HotelIdInfo'] = _HOTELIDINFO
DESCRIPTOR.message_types_by_name['HotelClassInfo'] = _HOTELCLASSINFO
DESCRIPTOR.message_types_by_name['HotelCountryRegionInfo'] = _HOTELCOUNTRYREGIONINFO
DESCRIPTOR.message_types_by_name['HotelStateInfo'] = _HOTELSTATEINFO
DESCRIPTOR.message_types_by_name['HotelCityInfo'] = _HOTELCITYINFO
DESCRIPTOR.message_types_by_name['ListingCustomAttributeInfo'] = _LISTINGCUSTOMATTRIBUTEINFO
DESCRIPTOR.message_types_by_name['ProductBiddingCategoryInfo'] = _PRODUCTBIDDINGCATEGORYINFO
DESCRIPTOR.message_types_by_name['ProductChannelInfo'] = _PRODUCTCHANNELINFO
DESCRIPTOR.message_types_by_name['ProductChannelExclusivityInfo'] = _PRODUCTCHANNELEXCLUSIVITYINFO
DESCRIPTOR.message_types_by_name['ProductConditionInfo'] = _PRODUCTCONDITIONINFO
DESCRIPTOR.message_types_by_name['ProductItemIdInfo'] = _PRODUCTITEMIDINFO
DESCRIPTOR.message_types_by_name['ProductTypeInfo'] = _PRODUCTTYPEINFO
DESCRIPTOR.message_types_by_name['UnknownListingDimensionInfo'] = _UNKNOWNLISTINGDIMENSIONINFO
DESCRIPTOR.message_types_by_name['HotelDateSelectionTypeInfo'] = _HOTELDATESELECTIONTYPEINFO
DESCRIPTOR.message_types_by_name['HotelAdvanceBookingWindowInfo'] = _HOTELADVANCEBOOKINGWINDOWINFO
DESCRIPTOR.message_types_by_name['HotelLengthOfStayInfo'] = _HOTELLENGTHOFSTAYINFO
DESCRIPTOR.message_types_by_name['HotelCheckInDayInfo'] = _HOTELCHECKINDAYINFO
DESCRIPTOR.message_types_by_name['InteractionTypeInfo'] = _INTERACTIONTYPEINFO
DESCRIPTOR.message_types_by_name['AdScheduleInfo'] = _ADSCHEDULEINFO
DESCRIPTOR.message_types_by_name['AgeRangeInfo'] = _AGERANGEINFO
DESCRIPTOR.message_types_by_name['GenderInfo'] = _GENDERINFO
DESCRIPTOR.message_types_by_name['IncomeRangeInfo'] = _INCOMERANGEINFO
DESCRIPTOR.message_types_by_name['ParentalStatusInfo'] = _PARENTALSTATUSINFO
DESCRIPTOR.message_types_by_name['YouTubeVideoInfo'] = _YOUTUBEVIDEOINFO
DESCRIPTOR.message_types_by_name['YouTubeChannelInfo'] = _YOUTUBECHANNELINFO
DESCRIPTOR.message_types_by_name['UserListInfo'] = _USERLISTINFO
DESCRIPTOR.message_types_by_name['ProximityInfo'] = _PROXIMITYINFO
DESCRIPTOR.message_types_by_name['GeoPointInfo'] = _GEOPOINTINFO
DESCRIPTOR.message_types_by_name['AddressInfo'] = _ADDRESSINFO
DESCRIPTOR.message_types_by_name['TopicInfo'] = _TOPICINFO
DESCRIPTOR.message_types_by_name['LanguageInfo'] = _LANGUAGEINFO
DESCRIPTOR.message_types_by_name['IpBlockInfo'] = _IPBLOCKINFO
DESCRIPTOR.message_types_by_name['ContentLabelInfo'] = _CONTENTLABELINFO
DESCRIPTOR.message_types_by_name['CarrierInfo'] = _CARRIERINFO
DESCRIPTOR.message_types_by_name['UserInterestInfo'] = _USERINTERESTINFO
DESCRIPTOR.message_types_by_name['WebpageInfo'] = _WEBPAGEINFO
DESCRIPTOR.message_types_by_name['WebpageConditionInfo'] = _WEBPAGECONDITIONINFO
DESCRIPTOR.message_types_by_name['OperatingSystemVersionInfo'] = _OPERATINGSYSTEMVERSIONINFO
DESCRIPTOR.message_types_by_name['AppPaymentModelInfo'] = _APPPAYMENTMODELINFO
DESCRIPTOR.message_types_by_name['MobileDeviceInfo'] = _MOBILEDEVICEINFO
DESCRIPTOR.message_types_by_name['CustomAffinityInfo'] = _CUSTOMAFFINITYINFO
DESCRIPTOR.message_types_by_name['CustomIntentInfo'] = _CUSTOMINTENTINFO
DESCRIPTOR.message_types_by_name['LocationGroupInfo'] = _LOCATIONGROUPINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordInfo = _reflection.GeneratedProtocolMessageType('KeywordInfo', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A keyword criterion.
  
  
  Attributes:
      text:
          The text of the keyword (at most 80 characters and 10 words).
      match_type:
          The match type of the keyword.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.KeywordInfo)
  ))
_sym_db.RegisterMessage(KeywordInfo)

PlacementInfo = _reflection.GeneratedProtocolMessageType('PlacementInfo', (_message.Message,), dict(
  DESCRIPTOR = _PLACEMENTINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A placement criterion. This can be used to modify bids for sites when
  targeting the content network.
  
  
  Attributes:
      url:
          URL of the placement.  For example, "http://www.domain.com".
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PlacementInfo)
  ))
_sym_db.RegisterMessage(PlacementInfo)

MobileAppCategoryInfo = _reflection.GeneratedProtocolMessageType('MobileAppCategoryInfo', (_message.Message,), dict(
  DESCRIPTOR = _MOBILEAPPCATEGORYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A mobile app category criterion.
  
  
  Attributes:
      mobile_app_category_constant:
          The mobile app category constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.MobileAppCategoryInfo)
  ))
_sym_db.RegisterMessage(MobileAppCategoryInfo)

MobileApplicationInfo = _reflection.GeneratedProtocolMessageType('MobileApplicationInfo', (_message.Message,), dict(
  DESCRIPTOR = _MOBILEAPPLICATIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A mobile application criterion.
  
  
  Attributes:
      app_id:
          A string that uniquely identifies a mobile application to
          Google Ads API. The format of this string is
          "{platform}-{platform\_native\_id}", where platform is "1" for
          iOS apps and "2" for Android apps, and where
          platform\_native\_id is the mobile application identifier
          native to the corresponding platform. For iOS, this native
          identifier is the 9 digit string that appears at the end of an
          App Store URL (e.g., "476943146" for "Flood-It! 2" whose App
          Store link is http://itunes.apple.com/us/app/flood-
          it!-2/id476943146). For Android, this native identifier is the
          application's package name (e.g., "com.labpixies.colordrips"
          for "Color Drips" given Google Play link https://play.google.c
          om/store/apps/details?id=com.labpixies.colordrips). A well
          formed app id for Google Ads API would thus be "1-476943146"
          for iOS and "2-com.labpixies.colordrips" for Android. This
          field is required and must be set in CREATE operations.
      name:
          Name of this mobile application.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.MobileApplicationInfo)
  ))
_sym_db.RegisterMessage(MobileApplicationInfo)

LocationInfo = _reflection.GeneratedProtocolMessageType('LocationInfo', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A location criterion.
  
  
  Attributes:
      geo_target_constant:
          The geo target constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.LocationInfo)
  ))
_sym_db.RegisterMessage(LocationInfo)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A device criterion.
  
  
  Attributes:
      type:
          Type of the device.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.DeviceInfo)
  ))
_sym_db.RegisterMessage(DeviceInfo)

PreferredContentInfo = _reflection.GeneratedProtocolMessageType('PreferredContentInfo', (_message.Message,), dict(
  DESCRIPTOR = _PREFERREDCONTENTINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A preferred content criterion.
  
  
  Attributes:
      type:
          Type of the preferred content.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PreferredContentInfo)
  ))
_sym_db.RegisterMessage(PreferredContentInfo)

ListingGroupInfo = _reflection.GeneratedProtocolMessageType('ListingGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _LISTINGGROUPINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A listing group criterion.
  
  
  Attributes:
      type:
          Type of the listing group.
      case_value:
          Dimension value with which this listing group is refining its
          parent. Undefined for the root group.
      parent_ad_group_criterion:
          Resource name of ad group criterion which is the parent
          listing group subdivision. Null for the root group.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ListingGroupInfo)
  ))
_sym_db.RegisterMessage(ListingGroupInfo)

ListingScopeInfo = _reflection.GeneratedProtocolMessageType('ListingScopeInfo', (_message.Message,), dict(
  DESCRIPTOR = _LISTINGSCOPEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A listing scope criterion.
  
  
  Attributes:
      dimensions:
          Scope of the campaign criterion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ListingScopeInfo)
  ))
_sym_db.RegisterMessage(ListingScopeInfo)

ListingDimensionInfo = _reflection.GeneratedProtocolMessageType('ListingDimensionInfo', (_message.Message,), dict(
  DESCRIPTOR = _LISTINGDIMENSIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Listing dimensions for listing group criterion.
  
  
  Attributes:
      dimension:
          Dimension of one of the types below is always present.
      listing_brand:
          Brand of the listing.
      hotel_id:
          Advertiser-specific hotel ID.
      hotel_class:
          Class of the hotel as a number of stars 1 to 5.
      hotel_country_region:
          Country or Region the hotel is located in.
      hotel_state:
          State the hotel is located in.
      hotel_city:
          City the hotel is located in.
      listing_custom_attribute:
          Listing custom attribute.
      product_bidding_category:
          Bidding category of a product offer.
      product_channel:
          Locality of a product offer.
      product_channel_exclusivity:
          Availability of a product offer.
      product_condition:
          Condition of a product offer.
      product_item_id:
          Item id of a product offer.
      product_type:
          Type of a product offer.
      unknown_listing_dimension:
          Unknown dimension. Set when no other listing dimension is set.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ListingDimensionInfo)
  ))
_sym_db.RegisterMessage(ListingDimensionInfo)

ListingBrandInfo = _reflection.GeneratedProtocolMessageType('ListingBrandInfo', (_message.Message,), dict(
  DESCRIPTOR = _LISTINGBRANDINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Brand of the listing.
  
  
  Attributes:
      value:
          String value of the listing brand.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ListingBrandInfo)
  ))
_sym_db.RegisterMessage(ListingBrandInfo)

HotelIdInfo = _reflection.GeneratedProtocolMessageType('HotelIdInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELIDINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Advertiser-specific hotel ID.
  
  
  Attributes:
      value:
          String value of the hotel ID.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelIdInfo)
  ))
_sym_db.RegisterMessage(HotelIdInfo)

HotelClassInfo = _reflection.GeneratedProtocolMessageType('HotelClassInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELCLASSINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Class of the hotel as a number of stars 1 to 5.
  
  
  Attributes:
      value:
          Long value of the hotel class.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelClassInfo)
  ))
_sym_db.RegisterMessage(HotelClassInfo)

HotelCountryRegionInfo = _reflection.GeneratedProtocolMessageType('HotelCountryRegionInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELCOUNTRYREGIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Country or Region the hotel is located in.
  
  
  Attributes:
      country_region_criterion:
          The Geo Target Constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelCountryRegionInfo)
  ))
_sym_db.RegisterMessage(HotelCountryRegionInfo)

HotelStateInfo = _reflection.GeneratedProtocolMessageType('HotelStateInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELSTATEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """State the hotel is located in.
  
  
  Attributes:
      state_criterion:
          The Geo Target Constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelStateInfo)
  ))
_sym_db.RegisterMessage(HotelStateInfo)

HotelCityInfo = _reflection.GeneratedProtocolMessageType('HotelCityInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELCITYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """City the hotel is located in.
  
  
  Attributes:
      city_criterion:
          The Geo Target Constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelCityInfo)
  ))
_sym_db.RegisterMessage(HotelCityInfo)

ListingCustomAttributeInfo = _reflection.GeneratedProtocolMessageType('ListingCustomAttributeInfo', (_message.Message,), dict(
  DESCRIPTOR = _LISTINGCUSTOMATTRIBUTEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Listing custom attribute.
  
  
  Attributes:
      value:
          String value of the listing custom attribute.
      index:
          Indicates the index of the custom attribute.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ListingCustomAttributeInfo)
  ))
_sym_db.RegisterMessage(ListingCustomAttributeInfo)

ProductBiddingCategoryInfo = _reflection.GeneratedProtocolMessageType('ProductBiddingCategoryInfo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTBIDDINGCATEGORYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Bidding category of a product offer.
  
  
  Attributes:
      id:
          ID of the product bidding category.  This ID is equivalent to
          the google\_product\_category ID as described in this article:
          https://support.google.com/merchants/answer/6324436.
      country_code:
          Two-letter upper-case country code of the product bidding
          category. It must match the
          campaign.shopping\_setting.sales\_country field.
      level:
          Level of the product bidding category.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProductBiddingCategoryInfo)
  ))
_sym_db.RegisterMessage(ProductBiddingCategoryInfo)

ProductChannelInfo = _reflection.GeneratedProtocolMessageType('ProductChannelInfo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTCHANNELINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Locality of a product offer.
  
  
  Attributes:
      channel:
          Value of the locality.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProductChannelInfo)
  ))
_sym_db.RegisterMessage(ProductChannelInfo)

ProductChannelExclusivityInfo = _reflection.GeneratedProtocolMessageType('ProductChannelExclusivityInfo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTCHANNELEXCLUSIVITYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Availability of a product offer.
  
  
  Attributes:
      channel_exclusivity:
          Value of the availability.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProductChannelExclusivityInfo)
  ))
_sym_db.RegisterMessage(ProductChannelExclusivityInfo)

ProductConditionInfo = _reflection.GeneratedProtocolMessageType('ProductConditionInfo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTCONDITIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Condition of a product offer.
  
  
  Attributes:
      condition:
          Value of the condition.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProductConditionInfo)
  ))
_sym_db.RegisterMessage(ProductConditionInfo)

ProductItemIdInfo = _reflection.GeneratedProtocolMessageType('ProductItemIdInfo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTITEMIDINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Item id of a product offer.
  
  
  Attributes:
      value:
          Value of the id.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProductItemIdInfo)
  ))
_sym_db.RegisterMessage(ProductItemIdInfo)

ProductTypeInfo = _reflection.GeneratedProtocolMessageType('ProductTypeInfo', (_message.Message,), dict(
  DESCRIPTOR = _PRODUCTTYPEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Type of a product offer.
  
  
  Attributes:
      value:
          Value of the type.
      level:
          Level of the type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProductTypeInfo)
  ))
_sym_db.RegisterMessage(ProductTypeInfo)

UnknownListingDimensionInfo = _reflection.GeneratedProtocolMessageType('UnknownListingDimensionInfo', (_message.Message,), dict(
  DESCRIPTOR = _UNKNOWNLISTINGDIMENSIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Unknown listing dimension.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.UnknownListingDimensionInfo)
  ))
_sym_db.RegisterMessage(UnknownListingDimensionInfo)

HotelDateSelectionTypeInfo = _reflection.GeneratedProtocolMessageType('HotelDateSelectionTypeInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELDATESELECTIONTYPEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Criterion for hotel date selection (default dates vs. user selected).
  
  
  Attributes:
      type:
          Type of the hotel date selection
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelDateSelectionTypeInfo)
  ))
_sym_db.RegisterMessage(HotelDateSelectionTypeInfo)

HotelAdvanceBookingWindowInfo = _reflection.GeneratedProtocolMessageType('HotelAdvanceBookingWindowInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELADVANCEBOOKINGWINDOWINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Criterion for number of days prior to the stay the booking is being
  made.
  
  
  Attributes:
      min_days:
          Low end of the number of days prior to the stay.
      max_days:
          High end of the number of days prior to the stay.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelAdvanceBookingWindowInfo)
  ))
_sym_db.RegisterMessage(HotelAdvanceBookingWindowInfo)

HotelLengthOfStayInfo = _reflection.GeneratedProtocolMessageType('HotelLengthOfStayInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELLENGTHOFSTAYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Criterion for length of hotel stay in nights.
  
  
  Attributes:
      min_nights:
          Low end of the number of nights in the stay.
      max_nights:
          High end of the number of nights in the stay.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelLengthOfStayInfo)
  ))
_sym_db.RegisterMessage(HotelLengthOfStayInfo)

HotelCheckInDayInfo = _reflection.GeneratedProtocolMessageType('HotelCheckInDayInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELCHECKINDAYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Criterion for day of the week the booking is for.
  
  
  Attributes:
      day_of_week:
          The day of the week.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.HotelCheckInDayInfo)
  ))
_sym_db.RegisterMessage(HotelCheckInDayInfo)

InteractionTypeInfo = _reflection.GeneratedProtocolMessageType('InteractionTypeInfo', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIONTYPEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Criterion for Interaction Type.
  
  
  Attributes:
      type:
          The interaction type.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.InteractionTypeInfo)
  ))
_sym_db.RegisterMessage(InteractionTypeInfo)

AdScheduleInfo = _reflection.GeneratedProtocolMessageType('AdScheduleInfo', (_message.Message,), dict(
  DESCRIPTOR = _ADSCHEDULEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Represents an AdSchedule criterion.
  
  AdSchedule is specified as the day of the week and a time interval
  within which ads will be shown.
  
  No more than six AdSchedules can be added for the same day.
  
  
  Attributes:
      start_minute:
          Minutes after the start hour at which this schedule starts.
          This field is required for CREATE operations and is prohibited
          on UPDATE operations.
      end_minute:
          Minutes after the end hour at which this schedule ends. The
          schedule is exclusive of the end minute.  This field is
          required for CREATE operations and is prohibited on UPDATE
          operations.
      start_hour:
          Starting hour in 24 hour time. This field must be between 0
          and 23, inclusive.  This field is required for CREATE
          operations and is prohibited on UPDATE operations.
      end_hour:
          Ending hour in 24 hour time; 24 signifies end of the day. This
          field must be between 0 and 24, inclusive.  This field is
          required for CREATE operations and is prohibited on UPDATE
          operations.
      day_of_week:
          Day of the week the schedule applies to.  This field is
          required for CREATE operations and is prohibited on UPDATE
          operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.AdScheduleInfo)
  ))
_sym_db.RegisterMessage(AdScheduleInfo)

AgeRangeInfo = _reflection.GeneratedProtocolMessageType('AgeRangeInfo', (_message.Message,), dict(
  DESCRIPTOR = _AGERANGEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """An age range criterion.
  
  
  Attributes:
      type:
          Type of the age range.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.AgeRangeInfo)
  ))
_sym_db.RegisterMessage(AgeRangeInfo)

GenderInfo = _reflection.GeneratedProtocolMessageType('GenderInfo', (_message.Message,), dict(
  DESCRIPTOR = _GENDERINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A gender criterion.
  
  
  Attributes:
      type:
          Type of the gender.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.GenderInfo)
  ))
_sym_db.RegisterMessage(GenderInfo)

IncomeRangeInfo = _reflection.GeneratedProtocolMessageType('IncomeRangeInfo', (_message.Message,), dict(
  DESCRIPTOR = _INCOMERANGEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """An income range criterion.
  
  
  Attributes:
      type:
          Type of the income range.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.IncomeRangeInfo)
  ))
_sym_db.RegisterMessage(IncomeRangeInfo)

ParentalStatusInfo = _reflection.GeneratedProtocolMessageType('ParentalStatusInfo', (_message.Message,), dict(
  DESCRIPTOR = _PARENTALSTATUSINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A parental status criterion.
  
  
  Attributes:
      type:
          Type of the parental status.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ParentalStatusInfo)
  ))
_sym_db.RegisterMessage(ParentalStatusInfo)

YouTubeVideoInfo = _reflection.GeneratedProtocolMessageType('YouTubeVideoInfo', (_message.Message,), dict(
  DESCRIPTOR = _YOUTUBEVIDEOINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A YouTube Video criterion.
  
  
  Attributes:
      video_id:
          YouTube video id as it appears on the YouTube watch page.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.YouTubeVideoInfo)
  ))
_sym_db.RegisterMessage(YouTubeVideoInfo)

YouTubeChannelInfo = _reflection.GeneratedProtocolMessageType('YouTubeChannelInfo', (_message.Message,), dict(
  DESCRIPTOR = _YOUTUBECHANNELINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A YouTube Channel criterion.
  
  
  Attributes:
      channel_id:
          The YouTube uploader channel id or the channel code of a
          YouTube channel.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.YouTubeChannelInfo)
  ))
_sym_db.RegisterMessage(YouTubeChannelInfo)

UserListInfo = _reflection.GeneratedProtocolMessageType('UserListInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERLISTINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A User List criterion. Represents a user list that is defined by the
  advertiser to be targeted.
  
  
  Attributes:
      user_list:
          The User List resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.UserListInfo)
  ))
_sym_db.RegisterMessage(UserListInfo)

ProximityInfo = _reflection.GeneratedProtocolMessageType('ProximityInfo', (_message.Message,), dict(
  DESCRIPTOR = _PROXIMITYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A Proximity criterion. The geo point and radius determine what
  geographical area is included. The address is a description of the geo
  point that does not affect ad serving.
  
  There are two ways to create a proximity. First, by setting an address
  and radius. The geo point will be automatically computed. Second, by
  setting a geo point and radius. The address is an optional label that
  won't be validated.
  
  
  Attributes:
      geo_point:
          Latitude and longitude.
      radius:
          The radius of the proximity.
      radius_units:
          The unit of measurement of the radius. Default is KILOMETERS.
      address:
          Full address.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ProximityInfo)
  ))
_sym_db.RegisterMessage(ProximityInfo)

GeoPointInfo = _reflection.GeneratedProtocolMessageType('GeoPointInfo', (_message.Message,), dict(
  DESCRIPTOR = _GEOPOINTINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Geo point for proximity criterion.
  
  
  Attributes:
      longitude_in_micro_degrees:
          Micro degrees for the longitude.
      latitude_in_micro_degrees:
          Micro degrees for the latitude.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.GeoPointInfo)
  ))
_sym_db.RegisterMessage(GeoPointInfo)

AddressInfo = _reflection.GeneratedProtocolMessageType('AddressInfo', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESSINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Address for proximity criterion.
  
  
  Attributes:
      postal_code:
          Postal code.
      province_code:
          Province or state code.
      country_code:
          Country code.
      province_name:
          Province or state name.
      street_address:
          Street address line 1.
      street_address2:
          Street address line 2. This field is write-only. It is only
          used for calculating the longitude and latitude of an address
          when geo\_point is empty.
      city_name:
          Name of the city.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.AddressInfo)
  ))
_sym_db.RegisterMessage(AddressInfo)

TopicInfo = _reflection.GeneratedProtocolMessageType('TopicInfo', (_message.Message,), dict(
  DESCRIPTOR = _TOPICINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A topic criterion. Use topics to target or exclude placements in the
  Google Display Network based on the category into which the placement
  falls (for example, "Pets & Animals/Pets/Dogs").
  
  
  Attributes:
      topic_constant:
          The Topic Constant resource name.
      path:
          The category to target or exclude. Each subsequent element in
          the array describes a more specific sub-category. For example,
          "Pets & Animals", "Pets", "Dogs" represents the "Pets &
          Animals/Pets/Dogs" category.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.TopicInfo)
  ))
_sym_db.RegisterMessage(TopicInfo)

LanguageInfo = _reflection.GeneratedProtocolMessageType('LanguageInfo', (_message.Message,), dict(
  DESCRIPTOR = _LANGUAGEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A language criterion.
  
  
  Attributes:
      language_constant:
          The language constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.LanguageInfo)
  ))
_sym_db.RegisterMessage(LanguageInfo)

IpBlockInfo = _reflection.GeneratedProtocolMessageType('IpBlockInfo', (_message.Message,), dict(
  DESCRIPTOR = _IPBLOCKINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """An IpBlock criterion used for IP exclusions. We allow: - IPv4 and IPv6
  addresses - individual addresses (192.168.0.1) - masks for individual
  addresses (192.168.0.1/32) - masks for Class C networks (192.168.0.1/24)
  
  
  Attributes:
      ip_address:
          The IP address of this IP block.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.IpBlockInfo)
  ))
_sym_db.RegisterMessage(IpBlockInfo)

ContentLabelInfo = _reflection.GeneratedProtocolMessageType('ContentLabelInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONTENTLABELINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Content Label for category exclusion.
  
  
  Attributes:
      type:
          Content label type, required for CREATE operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.ContentLabelInfo)
  ))
_sym_db.RegisterMessage(ContentLabelInfo)

CarrierInfo = _reflection.GeneratedProtocolMessageType('CarrierInfo', (_message.Message,), dict(
  DESCRIPTOR = _CARRIERINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Represents a Carrier Criterion.
  
  
  Attributes:
      carrier_constant:
          The Carrier constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CarrierInfo)
  ))
_sym_db.RegisterMessage(CarrierInfo)

UserInterestInfo = _reflection.GeneratedProtocolMessageType('UserInterestInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINTERESTINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Represents a particular interest-based topic to be targeted.
  
  
  Attributes:
      user_interest_category:
          The UserInterest resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.UserInterestInfo)
  ))
_sym_db.RegisterMessage(UserInterestInfo)

WebpageInfo = _reflection.GeneratedProtocolMessageType('WebpageInfo', (_message.Message,), dict(
  DESCRIPTOR = _WEBPAGEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Represents a criterion for targeting webpages of an advertiser's
  website.
  
  
  Attributes:
      criterion_name:
          The name of the criterion that is defined by this parameter.
          The name value will be used for identifying, sorting and
          filtering criteria with this type of parameters.  This field
          is required for CREATE operations and is prohibited on UPDATE
          operations.
      conditions:
          Conditions, or logical expressions, for webpage targeting. The
          list of webpage targeting conditions are and-ed together when
          evaluated for targeting.  This field is required for CREATE
          operations and is prohibited on UPDATE operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.WebpageInfo)
  ))
_sym_db.RegisterMessage(WebpageInfo)

WebpageConditionInfo = _reflection.GeneratedProtocolMessageType('WebpageConditionInfo', (_message.Message,), dict(
  DESCRIPTOR = _WEBPAGECONDITIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Logical expression for targeting webpages of an advertiser's website.
  
  
  Attributes:
      operand:
          Operand of webpage targeting condition.
      operator:
          Operator of webpage targeting condition.
      argument:
          Argument of webpage targeting condition.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.WebpageConditionInfo)
  ))
_sym_db.RegisterMessage(WebpageConditionInfo)

OperatingSystemVersionInfo = _reflection.GeneratedProtocolMessageType('OperatingSystemVersionInfo', (_message.Message,), dict(
  DESCRIPTOR = _OPERATINGSYSTEMVERSIONINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """Represents an operating system version to be targeted.
  
  
  Attributes:
      operating_system_version_constant:
          The operating system version constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.OperatingSystemVersionInfo)
  ))
_sym_db.RegisterMessage(OperatingSystemVersionInfo)

AppPaymentModelInfo = _reflection.GeneratedProtocolMessageType('AppPaymentModelInfo', (_message.Message,), dict(
  DESCRIPTOR = _APPPAYMENTMODELINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """An app payment model criterion.
  
  
  Attributes:
      type:
          Type of the app payment model.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.AppPaymentModelInfo)
  ))
_sym_db.RegisterMessage(AppPaymentModelInfo)

MobileDeviceInfo = _reflection.GeneratedProtocolMessageType('MobileDeviceInfo', (_message.Message,), dict(
  DESCRIPTOR = _MOBILEDEVICEINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A mobile device criterion.
  
  
  Attributes:
      mobile_device_constant:
          The mobile device constant resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.MobileDeviceInfo)
  ))
_sym_db.RegisterMessage(MobileDeviceInfo)

CustomAffinityInfo = _reflection.GeneratedProtocolMessageType('CustomAffinityInfo', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMAFFINITYINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A custom affinity criterion. A criterion of this type is only
  targetable.
  
  
  Attributes:
      custom_affinity:
          The CustomInterest resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CustomAffinityInfo)
  ))
_sym_db.RegisterMessage(CustomAffinityInfo)

CustomIntentInfo = _reflection.GeneratedProtocolMessageType('CustomIntentInfo', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMINTENTINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A custom intent criterion. A criterion of this type is only targetable.
  
  
  Attributes:
      custom_intent:
          The CustomInterest resource name.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.CustomIntentInfo)
  ))
_sym_db.RegisterMessage(CustomIntentInfo)

LocationGroupInfo = _reflection.GeneratedProtocolMessageType('LocationGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONGROUPINFO,
  __module__ = 'google.ads.googleads_v1.proto.common.criteria_pb2'
  ,
  __doc__ = """A radius around a list of locations specified via a feed.
  
  
  Attributes:
      feed:
          Feed specifying locations for targeting. This is required and
          must be set in CREATE operations.
      geo_target_constants:
          Geo target constant(s) restricting the scope of the geographic
          area within the feed. Currently only one geo target constant
          is allowed.
      radius:
          Distance in units specifying the radius around targeted
          locations. This is required and must be set in CREATE
          operations.
      radius_units:
          Unit of the radius, miles and meters supported currently. This
          is required and must be set in CREATE operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.LocationGroupInfo)
  ))
_sym_db.RegisterMessage(LocationGroupInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
